@@ -1,3 +1,4 @@
+import logging
 import os
 from collections import OrderedDict
 
@@ -40,9 +41,10 @@ class APIRequestor(object):
 
         abs_url = "{base_url}/{url}".format(base_url=api_base, url=url)
 
-        return self.request_base(method=method, url=abs_url, headers=headers, body=body, params=params, api_key=token)
+        return self.request_base(method=method, url=abs_url, headers=headers, body=body, params=params, api_key=token)[0]
 
-    def request_base(self, method, url, headers=None, body=None, params=None, api_key=None):
+    def request_base(self, method, url, headers=None, body=None, params=None, api_key=None, wrap_response=False):
+        retval = None
         if method not in ['GET', 'POST', 'PUT', 'DELETE', 'PATCH']:
             raise APIConnectionError(
                 "Unrecognized HTTP method {method}. This may indicate a bug in the Whatify "
@@ -53,7 +55,13 @@ class APIRequestor(object):
         rheaders.update(**(headers or {}))
         params = {'jwt': api_key, **(params or {})}
         response = self._http_client.request(method=method, url=url, headers=rheaders, json=body, params=params)
-        return self._handle_response(response)
+        try:
+            retval = self._handle_response(response)
+        except:
+            logging.info('Failed to get API response')
+            if not wrap_response:
+                raise APIError(response.content)
+        return retval, response.content
 
     def post(self, url, headers=None, body=None, params=None, api_key=None):
         return self.request("POST", url, headers, body, params, api_key)
