@@ -130,7 +130,7 @@ class MyWhatify:
 
     @classmethod
     def get_magento(cls, table: str = None, page: str = None, limit: str = None, add_total: str = None,
-                    only_total: str = None, get_df: bool=True):
+                    only_total: str = None, get_df: bool = True):
         '''
         GET magento store api
         :param table: the specific table
@@ -146,7 +146,7 @@ class MyWhatify:
 
     @classmethod
     def post_magento(cls, body: str = None, table: str = None, page: str = None, limit: str = None,
-                     add_total: str = None, only_total: str = None, get_df: bool=True):
+                     add_total: str = None, only_total: str = None, get_df: bool = True):
         '''
         POST magento store api
         :param body:
@@ -177,7 +177,7 @@ class MyWhatify:
 
     @classmethod
     def magento_api(cls, api_method: str, body: str = None, table: str = None, page: str = None,
-                    limit: str = None, addtotal: str = None, onlytotal: str = None, get_df: bool=True):
+                    limit: str = None, addtotal: str = None, onlytotal: str = None, get_df: bool=True, wrap_response=True):
         '''
         magento store api with params in query
         :param api_method: set the relevant method GET/POST... MANDATORY
@@ -190,7 +190,8 @@ class MyWhatify:
         :param get_df: change the return json into DataFrame
         :return:
         '''
-        retval = None
+        response = None
+        error = None
         base_url = cls.magento_magento2url + '?'
         base_vars = ['table', 'page', 'limit', 'addtotal', 'onlytotal']
         for var in base_vars:
@@ -198,15 +199,18 @@ class MyWhatify:
                 base_url += str(var) + '=' + str(locals().get(var)) + '&'
         base_url = base_url[:-1]
         try:
-            retval = cls.base_api(url=base_url, method=api_method, headers=cls.magento_headers, body=body)
-        except Exception as e:
-            logging.info('Failed to get data from api') #, got error: ' + str(e))
-        if retval and get_df:
+            response, error = cls.base_api(url=base_url, method=api_method, headers=cls.magento_headers, body=body,
+                                       wrap_response=wrap_response)
+        except Exception as ex:
+            logging.info('Failed to get data from api got error')
+        if not response and error:
+            logging.info('Failed to get data from api got error: ' + str(error))
+        if response and get_df:
             try:
-                retval = pd.DataFrame.from_dict(retval['data']['rows'], orient='columns')
+                response = pd.DataFrame.from_dict(response['data']['rows'], orient='columns')
             except Exception as ex:
-                logging.info('Failed to convert data into DataFrame') #, got error: ' + str(ex))
-        return retval
+                logging.info('Failed to convert data into DataFrame')
+        return response
 
     #############################
     #######    API's      #######
@@ -500,9 +504,9 @@ class MyWhatify:
         return func(url=url, headers=headers, body=body, params=params, user_token=user_token)
 
     @classmethod
-    def base_api(cls, url, method, headers=None, body=None, params=None, user_token=None):
+    def base_api(cls, url, method, headers=None, body=None, params=None, user_token=None, wrap_response=False):
         return APIRequestor().request_base(method=method, url=url, headers=headers, body=body, params=params,
-                                           api_key=user_token)
+                                           api_key=user_token, wrap_response=wrap_response)
 
     @classmethod
     def test_api(cls, url, method, expected_response, headers=None, body=None, params=None, user_token=None):
